'use strict';

const Transform = require('stream').Transform;

//noinspection JSUnusedLocalSymbols
/**
 * Transform PDF text content object to string
 * @type {JSONTransform}
 */
module.exports = class JSONTransform extends Transform {

  /**
   * Transform text object to string.
   */
  constructor() {
    super({
      writableObjectMode: true,
      readableObjectMode: false
    });
  }

  //noinspection JSUnusedLocalSymbols
  /**
   * Transform PDF.js text object to string
   * @param {Object} obj
   * @param {number} [obj.numPages] Number of pages in the document
   * @param {Object} [obj.metadata] PDF metadata
   * @param {number} [obj.page] Current page number
   * @param {Object} [obj.textContent] PDF.js page text content
   * @param [encoding]
   * @param cb
   * @private
   */
  _transform(obj, encoding, cb) {
    // Skip objects without `textContent`
    if (!obj) {
      //console.log(JSON.stringify(obj));
      cb();
      return;
    }
    this.push(
      JSON.stringify(
        obj
      )
    );

    cb();
  }
};
